@@ -46,7 +46,7 @@ import sys
 from typing import TYPE_CHECKING
 
 
-__version__ = "1.2.4"
+__version__ = "1.3.1"
 
 # Alphabetical order of definitions is ensured in tests
 # WARNING: any comment added in this dictionary definition will be lost when
@@ -112,6 +112,7 @@ _SUBMOD_ATTRS = {
         "webhook_endpoint",
     ],
     "cli._cli_utils": [
+        "check_cli_update",
         "typer_factory",
     ],
     "community": [
@@ -213,12 +214,14 @@ _SUBMOD_ATTRS = {
         "edit_discussion_comment",
         "enable_webhook",
         "fetch_job_logs",
+        "fetch_job_metrics",
         "file_exists",
         "get_collection",
         "get_dataset_tags",
         "get_discussion_details",
         "get_full_repo_name",
         "get_inference_endpoint",
+        "get_local_safetensors_metadata",
         "get_model_tags",
         "get_organization_overview",
         "get_paths_info",
@@ -259,6 +262,7 @@ _SUBMOD_ATTRS = {
         "model_info",
         "move_repo",
         "paper_info",
+        "parse_local_safetensors_file_metadata",
         "parse_safetensors_file_metadata",
         "pause_inference_endpoint",
         "pause_space",
@@ -380,6 +384,14 @@ _SUBMOD_ATTRS = {
         "ImageSegmentationOutputElement",
         "ImageSegmentationParameters",
         "ImageSegmentationSubtask",
+        "ImageTextToImageInput",
+        "ImageTextToImageOutput",
+        "ImageTextToImageParameters",
+        "ImageTextToImageTargetSize",
+        "ImageTextToVideoInput",
+        "ImageTextToVideoOutput",
+        "ImageTextToVideoParameters",
+        "ImageTextToVideoTargetSize",
         "ImageToImageInput",
         "ImageToImageOutput",
         "ImageToImageParameters",
@@ -665,6 +677,14 @@ __all__ = [
     "ImageSegmentationOutputElement",
     "ImageSegmentationParameters",
     "ImageSegmentationSubtask",
+    "ImageTextToImageInput",
+    "ImageTextToImageOutput",
+    "ImageTextToImageParameters",
+    "ImageTextToImageTargetSize",
+    "ImageTextToVideoInput",
+    "ImageTextToVideoOutput",
+    "ImageTextToVideoParameters",
+    "ImageTextToVideoTargetSize",
     "ImageToImageInput",
     "ImageToImageOutput",
     "ImageToImageParameters",
@@ -828,6 +848,7 @@ __all__ = [
     "cancel_access_request",
     "cancel_job",
     "change_discussion_status",
+    "check_cli_update",
     "close_session",
     "comment_discussion",
     "create_branch",
@@ -864,6 +885,7 @@ __all__ = [
     "export_entries_as_dduf",
     "export_folder_as_dduf",
     "fetch_job_logs",
+    "fetch_job_metrics",
     "file_exists",
     "from_pretrained_fastai",
     "get_async_session",
@@ -873,6 +895,7 @@ __all__ = [
     "get_full_repo_name",
     "get_hf_file_metadata",
     "get_inference_endpoint",
+    "get_local_safetensors_metadata",
     "get_model_tags",
     "get_organization_overview",
     "get_paths_info",
@@ -934,6 +957,7 @@ __all__ = [
     "notebook_login",
     "paper_info",
     "parse_huggingface_oauth",
+    "parse_local_safetensors_file_metadata",
     "parse_safetensors_file_metadata",
     "pause_inference_endpoint",
     "pause_space",
@@ -1139,7 +1163,10 @@ if TYPE_CHECKING:  # pragma: no cover
         WebhooksServer,  # noqa: F401
         webhook_endpoint,  # noqa: F401
     )
-    from .cli._cli_utils import typer_factory  # noqa: F401
+    from .cli._cli_utils import (
+        check_cli_update,  # noqa: F401
+        typer_factory,  # noqa: F401
+    )
     from .community import (
         Discussion,  # noqa: F401
         DiscussionComment,  # noqa: F401
@@ -1239,12 +1266,14 @@ if TYPE_CHECKING:  # pragma: no cover
         edit_discussion_comment,  # noqa: F401
         enable_webhook,  # noqa: F401
         fetch_job_logs,  # noqa: F401
+        fetch_job_metrics,  # noqa: F401
         file_exists,  # noqa: F401
         get_collection,  # noqa: F401
         get_dataset_tags,  # noqa: F401
         get_discussion_details,  # noqa: F401
         get_full_repo_name,  # noqa: F401
         get_inference_endpoint,  # noqa: F401
+        get_local_safetensors_metadata,  # noqa: F401
         get_model_tags,  # noqa: F401
         get_organization_overview,  # noqa: F401
         get_paths_info,  # noqa: F401
@@ -1285,6 +1314,7 @@ if TYPE_CHECKING:  # pragma: no cover
         model_info,  # noqa: F401
         move_repo,  # noqa: F401
         paper_info,  # noqa: F401
+        parse_local_safetensors_file_metadata,  # noqa: F401
         parse_safetensors_file_metadata,  # noqa: F401
         pause_inference_endpoint,  # noqa: F401
         pause_space,  # noqa: F401
@@ -1404,6 +1434,14 @@ if TYPE_CHECKING:  # pragma: no cover
         ImageSegmentationOutputElement,  # noqa: F401
         ImageSegmentationParameters,  # noqa: F401
         ImageSegmentationSubtask,  # noqa: F401
+        ImageTextToImageInput,  # noqa: F401
+        ImageTextToImageOutput,  # noqa: F401
+        ImageTextToImageParameters,  # noqa: F401
+        ImageTextToImageTargetSize,  # noqa: F401
+        ImageTextToVideoInput,  # noqa: F401
+        ImageTextToVideoOutput,  # noqa: F401
+        ImageTextToVideoParameters,  # noqa: F401
+        ImageTextToVideoTargetSize,  # noqa: F401
         ImageToImageInput,  # noqa: F401
         ImageToImageOutput,  # noqa: F401
         ImageToImageParameters,  # noqa: F401
